"""
###################################
census_geocoder/constants.py
###################################

Defines the constants that are used throughout the library.

"""

CENSUS_API_URL = 'https://geocoding.geo.census.gov'

BENCHMARKS = {
    'CURRENT': 'Public_AR_Current',
    'TAB2020': 'Public_AR_TAB2020',
    'CENSUS2020': 'Public_AR_Census2020'
}

VINTAGES = {
    'Public_AR_Current': {
        'CURRENT': 'Current_Current',
        'CENSUS2020': 'Census2020_Current',
        'ACS2019': 'ACS2019_Current',
        'ACS2018': 'ACS2018_Current',
        'ACS2017': 'ACS2017_Current',
        'CENSUS2010': 'Census2010_Current'
    },
    'Public_AR_Census2020': {
        'CENSUS2020': 'Census2020_Census2020',
        'CENSUS2010': 'Census2010_Census2020'
    },
    'Public_AR_TAB2020': {
        'CURRENT': 'Current_TAB2020',
        'CENSUS2020': 'Census2020_TAB2020',
        'ACS2019': 'ACS2019_TAB2020',
        'ACS2018': 'ACS2018_TAB2020',
        'ACS2017': 'ACS2017_TAB2020',
        'CENSUS2010': 'Census2010_TAB2020'
    }
}

LAYERS = {
    'Current_Current': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2020 Census ZIP Code Tabulation Areas': 2,
        '2020 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        '2020 Census Blocks': 12,
        'Census Blocks': 12,
        'Blocks': 12,
        'Unified School Districts': 14,
        'Secondary School Districts': 16,
        'Elementary School Districts': 18,
        'Estates': 20,
        'County Subdivisions': 22,
        'Subbarrios': 24,
        'Consolidated Cities': 26,
        'Incorporated Places': 28,
        'Census Designated Places': 30,
        'CDPs': 30,
        'Alaska Native Regional Corporations': 32,
        'Tribal Subdivisions': 34,
        'Federal American Indian Reservations': 36,
        'Off-Reservation Trust Lands': 38,
        'State American Indian Reservations': 40,
        'Hawaiian Home Lands': 42,
        'Alaska Native Village Statistical Areas': 44,
        'Oklahoma Tribal Statistical Areas': 46,
        'State Designated Tribal Stastical Areas': 48,
        'Tribal Designated Statistical Areas': 50,
        'American Indian Joint-Use Areas': 52,
        '116th Congressional Districts': 54,
        'Congressional Districts': 54,
        '2018 State Legislative Districts - Upper': 56,
        'State Legislative Districts - Upper': 56,
        '2018 State Legislative Districts - Lower': 58,
        'State Legislative Districts - Lower': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82
    },
    'Census2020_Current': {
        'Urban Growth Areas': 0,
        'Tribal Census Tracts': 2,
        'Tribal Block Groups': 4,
        'Census Tracts': 6,
        'Census Block Groups': 8,
        'Block Groups': 8,
        'Census Blocks': 10,
        'Blocks': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Voting Districts': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82,
        'Zip Code Tabulation Areas': 84,
        'ZCTAs': 84
    },
    'ACS2019_Current': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'ACS2018_Current': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'ACS2017_Current': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '115th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2016 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2016 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'Census2010_Current': {
        'Public Use Microdata Areas': 0,
        'PUMAs': 0,
        'Traffic Analysis Districts': 2,
        'TADs': 2,
        'Traffic Analysis Zones': 4,
        'TAZs': 4,
        'Urban Growth Areas': 6,
        'ZIP Code Tabulation Areas': 8,
        'Zip Code Tabulation Areas': 8,
        'ZCTAs': 8,
        'Tribal Census Tracts': 10,
        'Tribal Block Groups': 12,
        'Census Tracts': 14,
        'Census Block Groups': 16,
        'Census Blocks': 18,
        'Blocks': 18,
        'Unified School Districts': 20,
        'Secondary School Districts': 22,
        'Elementary School Districts': 24,
        'Estates': 26,
        'County Subdivisions': 28,
        'Subbarrios': 30,
        'Consolidated Cities': 32,
        'Incorporated Places': 34,
        'Census Designated Places': 36,
        'CDPs': 36,
        'Alaska Native Regional Corporations': 38,
        'Tribal Subdivisions': 40,
        'Federal American Indian Reservations': 42,
        'Off-Reservation Trust Lands': 44,
        'State American Indian Reservations': 46,
        'Hawaiian Home Lands': 48,
        'Alaska Native Village Statistical Areas': 50,
        'Oklahoma Tribal Statistical Areas': 52,
        'State Designated Tribal Stastical Areas': 54,
        'Tribal Designated Statistical Areas': 56,
        'American Indian Joint-Use Areas': 58,
        '113th Congressional Districts': 60,
        '111th Congressional Districts': 62,
        '2012 State Legislative Districts - Upper': 64,
        '2012 State Legislative Districts - Lower': 66,
        '2010 State Legislative Districts - Upper': 68,
        '2010 State Legislative Districts - Lower': 70,
        'Voting Districts': 72,
        'Census Divisions': 74,
        'Divisions': 74,
        'Census Regions': 76,
        'Regions': 76,
        'Urbanized Areas': 78,
        'Urban Clusters': 80,
        'Combined New England City and Town Areas': 82,
        'Combined NECTAs': 82,
        'New England City and Town Area Divisions': 84,
        'NECTA Divisions': 84,
        'Metropolitan New England City and Town Areas': 86,
        'Metropolitan NECTAs': 86,
        'Micropolitan New England City and Town Areas': 88,
        'Micropolitan NECTAs': 88,
        'Combined Statistical Areas': 90,
        'CSAs': 90,
        'Metropolitan Divisions': 92,
        'Metropolitan Statistical Areas': 94,
        'Micropolitan Statistical Areas': 96,
        'States': 98,
        'Counties': 100
    },
    'Census2020_Census2020': {
        'Urban Growth Areas': 0,
        'Tribal Census Tracts': 2,
        'Tribal Block Groups': 4,
        'Census Tracts': 6,
        'Census Block Groups': 8,
        'Block Groups': 8,
        'Census Blocks': 10,
        'Blocks': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Voting Districts': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82,
        'Zip Code Tabulation Areas': 84,
        'ZCTAs': 84
    },
    'Census2010_Census2020': {
        'Urban Growth Areas': 0,
        'Tribal Census Tracts': 2,
        'Tribal Block Groups': 4,
        'Census Tracts': 6,
        'Census Block Groups': 8,
        'Block Groups': 8,
        'Census Blocks': 10,
        'Blocks': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Voting Districts': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82,
        'Zip Code Tabulation Areas': 84,
        'ZCTAs': 84
    },
    'Current_TAB2020': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2020 Census ZIP Code Tabulation Areas': 2,
        '2020 Census Zip Code Tabulation Areas': 2,
        'Census Zip Code Tabulation Areas': 2,
        'Zip Code Tabulation Areas': 2,
        'ZIP Code Tabulation Areas': 2,
        '2020 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        '2020 Census Blocks': 12,
        'Census Blocks': 12,
        'Blocks': 12,
        'Unified School Districts': 14,
        'Secondary School Districts': 16,
        'Elementary School Districts': 18,
        'Estates': 20,
        'County Subdivisions': 22,
        'Subbarrios': 24,
        'Consolidated Cities': 26,
        'Incorporated Places': 28,
        'Census Designated Places': 30,
        'CDPs': 30,
        'Alaska Native Regional Corporations': 32,
        'Tribal Subdivisions': 34,
        'Federal American Indian Reservations': 36,
        'Off-Reservation Trust Lands': 38,
        'State American Indian Reservations': 40,
        'Hawaiian Home Lands': 42,
        'Alaska Native Village Statistical Areas': 44,
        'Oklahoma Tribal Statistical Areas': 46,
        'State Designated Tribal Stastical Areas': 48,
        'Tribal Designated Statistical Areas': 50,
        'American Indian Joint-Use Areas': 52,
        '116th Congressional Districts': 54,
        'Congressional Districts': 54,
        '2018 State Legislative Districts - Upper': 56,
        'State Legislative Districts - Upper': 56,
        '2018 State Legislative Districts - Lower': 58,
        'State Legislative Districts - Lower': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82
    },
    'Census2020_TAB2020': {
        'Urban Growth Areas': 0,
        'Tribal Census Tracts': 2,
        'Tribal Block Groups': 4,
        'Census Tracts': 6,
        'Census Block Groups': 8,
        'Block Groups': 8,
        'Census Blocks': 10,
        'Blocks': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Voting Districts': 58,
        'Census Divisions': 60,
        'Divisions': 60,
        'Census Regions': 62,
        'Regions': 62,
        'Combined New England City and Town Areas': 64,
        'Combined NECTAs': 64,
        'New England City and Town Area Divisions': 66,
        'NECTA Divisions': 66,
        'Metropolitan New England City and Town Areas': 68,
        'Metropolitan NECTAs': 68,
        'Micropolitan New England City and Town Areas': 70,
        'Micropolitan NECTAs': 70,
        'Combined Statistical Areas': 72,
        'CSAs': 72,
        'Metropolitan Divisions': 74,
        'Metropolitan Statistical Areas': 76,
        'Micropolitan Statistical Areas': 78,
        'States': 80,
        'Counties': 82,
        'Zip Code Tabulation Areas': 84,
        'ZCTAs': 84
    },
    'ACS2019_TAB2020': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'ACS2018_TAB2020': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '116th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2018 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2018 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'ACS2017_TAB2020': {
        '2010 Census Public Use Microdata Areas': 0,
        '2010 Census PUMAs': 0,
        '2010 PUMAs': 0,
        'Census Public Use Microdata Areas': 0,
        'Census PUMAs': 0,
        'PUMAs': 0,
        '2010 Census ZIP Code Tabulation Areas': 2,
        '2010 Census ZCTAs': 2,
        'Census ZCTAs': 2,
        'ZCTAs': 2,
        'Tribal Census Tracts': 4,
        'Tribal Block Groups': 6,
        'Census Tracts': 8,
        'Census Block Groups': 10,
        'Unified School Districts': 12,
        'Secondary School Districts': 14,
        'Elementary School Districts': 16,
        'Estates': 18,
        'County Subdivisions': 20,
        'Subbarrios': 22,
        'Consolidated Cities': 24,
        'Incorporated Places': 26,
        'Census Designated Places': 28,
        'CDPs': 28,
        'Alaska Native Regional Corporations': 30,
        'Tribal Subdivisions': 32,
        'Federal American Indian Reservations': 34,
        'Off-Reservation Trust Lands': 36,
        'State American Indian Reservations': 38,
        'Hawaiian Home Lands': 40,
        'Alaska Native Village Statistical Areas': 42,
        'Oklahoma Tribal Statistical Areas': 44,
        'State Designated Tribal Stastical Areas': 46,
        'Tribal Designated Statistical Areas': 48,
        'American Indian Joint-Use Areas': 50,
        '115th Congressional Districts': 52,
        'Congressional Districts': 52,
        '2016 State Legislative Districts - Upper': 54,
        'State Legislative Districts - Upper': 54,
        '2016 State Legislative Districts - Lower': 56,
        'State Legislative Districts - Lower': 56,
        'Census Divisions': 58,
        'Divisions': 58,
        'Census Regions': 60,
        'Regions': 60,
        '2010 Census Urbanized Areas': 62,
        'Census Urbanized Areas': 62,
        'Urbanized Areas': 62,
        '2010 Census Urban Clusters': 64,
        'Census Urban Clusters': 64,
        'Urban Clusters': 64,
        'Combined New England City and Town Areas': 66,
        'Combined NECTAs': 66,
        'New England City and Town Area Divisions': 68,
        'NECTA Divisions': 68,
        'Metropolitan New England City and Town Areas': 70,
        'Metropolitan NECTAs': 70,
        'Micropolitan New England City and Town Areas': 72,
        'Micropolitan NECTAs': 72,
        'Combined Statistical Areas': 74,
        'CSAs': 74,
        'Metropolitan Divisions': 76,
        'Metropolitan Statistical Areas': 78,
        'Micropolitan Statistical Areas': 80,
        'States': 82,
        'Counties': 84
    },
    'Census2010_TAB2020': {
        'Public Use Microdata Areas': 0,
        'PUMAs': 0,
        'Traffic Analysis Districts': 2,
        'TADs': 2,
        'Traffic Analysis Zones': 4,
        'TAZs': 4,
        'Urban Growth Areas': 6,
        'ZIP Code Tabulation Areas': 8,
        'Zip Code Tabulation Areas': 8,
        'ZCTAs': 8,
        'Tribal Census Tracts': 10,
        'Tribal Block Groups': 12,
        'Census Tracts': 14,
        'Census Block Groups': 16,
        'Census Blocks': 18,
        'Blocks': 18,
        'Unified School Districts': 20,
        'Secondary School Districts': 22,
        'Elementary School Districts': 24,
        'Estates': 26,
        'County Subdivisions': 28,
        'Subbarrios': 30,
        'Consolidated Cities': 32,
        'Incorporated Places': 34,
        'Census Designated Places': 36,
        'CDPs': 36,
        'Alaska Native Regional Corporations': 38,
        'Tribal Subdivisions': 40,
        'Federal American Indian Reservations': 42,
        'Off-Reservation Trust Lands': 44,
        'State American Indian Reservations': 46,
        'Hawaiian Home Lands': 48,
        'Alaska Native Village Statistical Areas': 50,
        'Oklahoma Tribal Statistical Areas': 52,
        'State Designated Tribal Stastical Areas': 54,
        'Tribal Designated Statistical Areas': 56,
        'American Indian Joint-Use Areas': 58,
        '113th Congressional Districts': 60,
        '111th Congressional Districts': 62,
        '2012 State Legislative Districts - Upper': 64,
        '2012 State Legislative Districts - Lower': 66,
        '2010 State Legislative Districts - Upper': 68,
        '2010 State Legislative Districts - Lower': 70,
        'Voting Districts': 72,
        'Census Divisions': 74,
        'Divisions': 74,
        'Census Regions': 76,
        'Regions': 76,
        'Urbanized Areas': 78,
        'Urban Clusters': 80,
        'Combined New England City and Town Areas': 82,
        'Combined NECTAs': 82,
        'New England City and Town Area Divisions': 84,
        'NECTA Divisions': 84,
        'Metropolitan New England City and Town Areas': 86,
        'Metropolitan NECTAs': 86,
        'Micropolitan New England City and Town Areas': 88,
        'Micropolitan NECTAs': 88,
        'Combined Statistical Areas': 90,
        'CSAs': 90,
        'Metropolitan Divisions': 92,
        'Metropolitan Statistical Areas': 94,
        'Micropolitan Statistical Areas': 96,
        'States': 98,
        'Counties': 100
    }
}

FUNCSTAT = {
    'A': 'Active Entity',
    'B': 'Active Government partially consolidated with another entity with some separate officials',
    'C': 'Active Government consolidated with a single set of officials',
    'E': 'Active Government providing special-purpose functions',
    'F': 'Fictitious Entity created to fill Census Bureau geographical hierarchy',
    'G': 'Active Government subordinate to other Government',
    'I': 'Inactive Government with power to provide primary special-purpose functions',
    'L': 'Inactive, Non-Functioning Legal Real Property',
    'M': 'Active Legal Real Property',
    'N': 'Non-functioning Legal Entity',
    'S': 'Statistical Entity',
    'T': 'Active State-recognized Entity'
}

LSAD = {
    '00': 'Undefined',
    '03': 'City and Borough (suffix)',
    '04': 'Borough (suffix)',
    '05': 'Census Area (suffix)',
    '06': 'County / Economic Census Place',
    '07': 'District (suffix)',
    '10': 'Island (suffix)',
    '12': 'Municipality (suffix)',
    '13': 'Municipio (suffix)',
    '15': 'Parish (suffix)',
    '20': 'barrio (suffix)',
    '21': 'borough (suffix)',
    '22': 'CCD',
    '23': 'census subarea (suffix)',
    '24': 'census subdistrict (suffix)',
    '25': 'city (suffix)',
    '26': 'county (suffix)',
    '27': 'district (suffix)',
    '28': 'District (prefix)',
    '29': 'precinct (suffix)',
    '30': 'Precinct (prefix)',
    '31': 'gore (suffix)',
    '32': 'grant (suffix)',
    '36': 'location (suffix)',
    '37': 'municipality (suffix)',
    '39': 'plantation (suffix)',
    '41': 'barrio-pueblo (suffix)',
    '42': 'purchase (suffix)',
    '43': 'town (suffix)',
    '44': 'township (suffix)',
    '45': 'Township (prefix)',
    '46': 'UT (suffix)',
    '47': 'village (suffix)',
    '49': 'charter township (suffix)',
    '51': 'subbarrio (suffix)',
    '53': 'city and borough (suffix)',
    '55': 'comunidad (suffix)',
    '57': 'CDP',
    '62': 'zona urbana (suffix)',
    '68': 'Region (suffix)',
    '69': 'Division (suffix)',
    '70': 'UGA (suffix)',
    '71': 'CMSA',
    '72': 'MSA',
    '73': 'Primary Metropolitan Statistical Area',
    '74': 'New England County Metropolitan Area',
    '75': 'Urbanized Area (suffix)',
    '76': 'Urban Cluster (suffix)',
    '77': 'Alaska Native Regional Corporation (suffix)',
    '78': 'Hawaiian Home Land (suffix)',
    '79': 'ANVSA (suffix)',
    '80': 'TDSA (suffix)',
    '81': 'Colony (suffix)',
    '82': 'Community (suffix)',
    '83': 'joint-use area (suffix)',
    '84': 'Pueblo (suffix)',
    '85': 'Rancheria (suffix)',
    '86': 'Reservation (suffix)',
    '87': 'Reserve (suffix)',
    '88': 'OTSA (suffix)',
    '89': 'Trust Land (suffix)',
    '90': 'joint-use OTSA (suffix)',
    '91': 'Ranch (suffix)',
    '92': 'SDTSA (suffix)',
    '93': 'Indian Village (suffix)',
    '94': 'Village (suffix)',
    '95': 'Indian Community (suffix)',
    '96': 'Indian Reservation (suffix)',
    '97': 'Indian Rancheria (suffix)',
    '98': 'Indian Colony (suffix)',
    '99': 'Pueblo de',
    '9C': 'Pueblo of',
    '9D': 'Ranch Reservation (suffix)',
    '9E': 'Rancheria Reservatio (suffix)',
    '9F': 'Ranches (suffix)',
    'B1': 'Balance of County',
    'B2': 'Balance of Parish',
    'B3': 'Balance of Borough',
    'B4': 'Balance of Census Area',
    'B5': 'town (balance)',
    'B6': 'township (balance)',
    'B7': 'charter township (balance)',
    'B8': 'Balance of',
    'BG': 'Block Group (prefix)',
    'BI': 'Balance of Island',
    'BK': 'Block (prefix)',
    'BL': '(balance)',
    'C1': 'Congressional District (at Large)',
    'C2': 'Congressional District (prefix)',
    'C3': 'Resident Commissioner District (at Large) (prefix)',
    'C4': 'Delegate District (at Large)',
    'C5': 'No Representative',
    'CB': 'consolidated government (balance)',
    'CG': 'consolidated government (suffix)',
    'CN': 'corporation (suffix)',
    'CR': 'Commercial Region (suffix)',
    'CT': 'Census Tract (prefix)',
    'IB': 'Tribal Block Group (prefix)',
    'IT': 'Tribal Census Tract (prefix)',
    'L1': 'Ward (prefix)',
    'L2': 'Senatorial District (suffix)',
    'L3': 'Assembly District (prefix)',
    'L4': 'General Assembly District (prefix)',
    'L5': 'State Legislature District (prefix)',
    'L6': 'State Legislature Subdistrict (prefix)',
    'L7': 'District',
    'LL': 'State House District (prefix)',
    'LU': 'State Senate District (prefix)',
    'M0': 'CSA (suffix)',
    'M1': 'Metro Area (suffix)',
    'M2': 'Micro Area (suffix)',
    'M3': 'Metro Division (suffix)',
    'M4': 'Combined NECTA (suffix)',
    'M5': 'Metropolitan NECTA (suffix)',
    'M6': 'Micropolitan NECTA (suffix)',
    'M7': 'NECTA Division (suffix)',
    'MB': 'metropolitan government (balance)',
    'MG': 'metropolitan government (suffix)',
    'MT': 'metro government (suffix)',
    'P1': 'SuperPUMA (prefix)',
    'P5': 'PUMA (prefix)',
    'T1': 'Area (suffix)',
    'T2': 'Chapter (suffix)',
    'T3': 'Segment (suffix)',
    'TA': 'Administrative Area (suffix)',
    'TB': 'Addition (suffix)',
    'TC': 'County District (prefix)',
    'TZ': 'TAZ (prefix)',
    'UB': 'unified government (balance)',
    'UC': 'urban county (suffix)',
    'UG': 'unified government (suffix)',
    'V1': 'Voting District (prefix)',
    'V2': 'Voting District (suffix)',
    'Z3': 'ZCTA3 (suffix)',
    'Z5': 'ZCTA5 (suffix)'
}
